summaryrefslogtreecommitdiff
path: root/cmake/filesource.cmake
diff options
context:
space:
mode:
Diffstat (limited to 'cmake/filesource.cmake')
-rw-r--r--cmake/filesource.cmake4
1 files changed, 2 insertions, 2 deletions
diff --git a/cmake/filesource.cmake b/cmake/filesource.cmake
index e02467633b..ff9fa360f6 100644
--- a/cmake/filesource.cmake
+++ b/cmake/filesource.cmake
@@ -1,5 +1,5 @@
-# Modify cmake/filesource-files.txt to change the source files for this target.
-load_sources_list(MBGL_FILESOURCE_FILES cmake/filesource-files.txt)
+# Modify platform/default/filesource-files.json to change the source files for this target.
+load_sources_list(MBGL_FILESOURCE_FILES platform/default/filesource-files.json)
add_library(mbgl-filesource STATIC ${MBGL_FILESOURCE_FILES})
target_include_directories(mbgl-filesource